@@ -15,6 +15,9 @@
 # You should have received a copy of the GNU General Public License
 # along with python-iam.  If not, see <https://www.gnu.org/licenses/>.
 """Declares :class:`~PhonenumberPrincipal`."""
+import phonenumbers
+from phonenumbers import NumberParseException
+
 from .principal import Principal
 
 
@@ -25,6 +28,17 @@ class PhonenumberPrincipal(Principal):
     resource_class = 'PhonenumberPrincipal'
     pattern = '^[+]*[(]{0,1}[0-9]{1,4}[)]{0,1}[-\s\./0-9]*$'
 
+    @classmethod
+    def iscapable(cls, value):
+        if not super().iscapable(value):
+            return False
+        try:
+            p = phonenumbers.parse(value, None)
+        except NumberParseException:
+            return False
+        return phonenumbers.is_possible_number(p)
+
+
     def __init__(self, value):
         super().__init__()
         self.value = value
