@@ -52,7 +52,8 @@ __all__ = [
 AUTH_USER_MODEL = 'iam.Subject'
 
 AUTHENTICATION_BACKENDS = [
-    'iam.ext.django.lib.backends.LocalSubjectBackend'
+    'iam.ext.django.lib.backends.LocalSubjectBackend',
+    'iam.ext.django.lib.backends.PhonenumberBackend'
 ]
 
 
